@@ -1,17 +1,17 @@
 abund <- function(formula, data, inits, priors, tuning,
 		  n.batch, batch.length, accept.rate = 0.43, family = 'Poisson',
 		  n.omp.threads = 1, verbose = TRUE,
-		  n.report = 100, n.burn = round(.10 * n.batch * batch.length), n.thin = 1, 
+		  n.report = 100, n.burn = round(.10 * n.batch * batch.length), n.thin = 1,
 		  n.chains = 1, save.fitted = TRUE, ...) {
 
   ptm <- proc.time()
-  
+
   if (!(family) %in% c('Poisson', 'NB', 'Gaussian', 'zi-Gaussian')) {
     stop("family must be either 'Poisson', 'NB', 'Gaussian', or 'zi-Gaussian'")
   }
   if (family %in% c('Gaussian', 'zi-Gaussian')) {
-    abundGaussian(formula, data, inits, priors, tuning, 
-		  n.batch, batch.length, accept.rate, family, 
+    abundGaussian(formula, data, inits, priors, tuning,
+		  n.batch, batch.length, accept.rate, family,
 		  n.omp.threads, verbose, n.report, n.burn, n.thin, n.chains, save.fitted)
   } else {
 
@@ -52,23 +52,23 @@ abund <- function(formula, data, inits, priors, tuning,
     if (!'y' %in% names(data)) {
       stop("error: data y must be specified in data")
     }
-    y <- as.matrix(data$y) 
+    y <- as.matrix(data$y)
     y.mat <- y
     # Offset
     if ('offset' %in% names(data)) {
       offset <- data$offset
       if (length(offset) == 1) {
-        offset <- matrix(offset, nrow(y), ncol(y)) 
+        offset <- matrix(offset, nrow(y), ncol(y))
       } else if (length(dim(offset)) == 1) { # Value for each site
         if (length(offset) != nrow(y)) {
-          stop(paste0("offset must be a single value, vector of length ", nrow(y), " or a matrix with ", 
-                     nrow(y), " rows and ", ncol(y), " columns."))	
+          stop(paste0("offset must be a single value, vector of length ", nrow(y), " or a matrix with ",
+                     nrow(y), " rows and ", ncol(y), " columns."))
         }
         offset <- matrix(offset, nrow(y), ncol(y))
       } else if (length(dim(offset)) == 2) { # Value for each site/obs
         if (nrow(offset) != nrow(y) | ncol(offset) != ncol(y)) {
-          stop(paste0("offset must be a single value, vector of length ", nrow(y), " or a matrix with ", 
-                      nrow(y), " rows and ", ncol(y), " columns."))	
+          stop(paste0("offset must be a single value, vector of length ", nrow(y), " or a matrix with ",
+                      nrow(y), " rows and ", ncol(y), " columns."))
 
         }
       }
@@ -118,14 +118,14 @@ abund <- function(formula, data, inits, priors, tuning,
     }
 
     # Check whether random effects are sent in as numeric, and
-    # return error if they are. 
+    # return error if they are.
     # Abundance -------------------------
     if (!is.null(findbars(formula))) {
       abund.re.names <- unique(unlist(sapply(findbars(formula), all.vars)))
       for (i in 1:length(abund.re.names)) {
         if (is(data$covs[, abund.re.names[i]], 'factor')) {
           stop(paste("error: random effect variable ", abund.re.names[i], " specified as a factor. Random effect variables must be specified as numeric.", sep = ''))
-        } 
+        }
         if (is(data$covs[, abund.re.names[i]], 'character')) {
           stop(paste("error: random effect variable ", abund.re.names[i], " specified as character. Random effect variables must be specified as numeric.", sep = ''))
         }
@@ -141,7 +141,7 @@ abund <- function(formula, data, inits, priors, tuning,
     # covs ------------------------------
     for (i in 1:ncol(data$covs)) {
       if (sum(is.na(data$covs[, i])) > sum(is.na(y))) {
-        stop("error: some elements in covs have missing values where there is an observed data value in y. Please either replace the NA values in covs with non-missing values (e.g., mean imputation) or set the corresponding values in y to NA where the covariate is missing.") 
+        stop("error: some elements in covs have missing values where there is an observed data value in y. Please either replace the NA values in covs with non-missing values (e.g., mean imputation) or set the corresponding values in y to NA where the covariate is missing.")
       }
     }
     # Misalignment between y and covs
@@ -211,9 +211,9 @@ abund <- function(formula, data, inits, priors, tuning,
     offset <- c(offset)
     names.long <- which(!is.na(y))
     # Remove missing observations when the covariate data are available but
-    # there are missing abundance data. 
+    # there are missing abundance data.
     if (nrow(X) == length(y)) {
-      X <- X[!is.na(y), , drop = FALSE]  
+      X <- X[!is.na(y), , drop = FALSE]
     }
     if (nrow(X.re) == length(y) & p.abund.re > 0) {
       X.re <- X.re[!is.na(y), , drop = FALSE]
@@ -277,7 +277,7 @@ abund <- function(formula, data, inits, priors, tuning,
       }
       mu.beta <- rep(0, p.abund)
       sigma.beta <- rep(100, p.abund)
-      Sigma.beta <- diag(p.abund) * sigma.beta 
+      Sigma.beta <- diag(p.abund) * sigma.beta
     }
     # sigma.sq.mu --------------------
     if (p.abund.re > 0) {
@@ -289,19 +289,19 @@ abund <- function(formula, data, inits, priors, tuning,
         sigma.sq.mu.b <- priors$sigma.sq.mu.ig[[2]]
         if (length(sigma.sq.mu.a) != p.abund.re & length(sigma.sq.mu.a) != 1) {
           if (p.abund.re == 1) {
-          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
           	   p.abund.re, " with elements corresponding to sigma.sq.mus' shape", sep = ""))
           } else {
-          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
           	   p.abund.re, " or 1 with elements corresponding to sigma.sq.mus' shape", sep = ""))
           }
         }
         if (length(sigma.sq.mu.b) != p.abund.re & length(sigma.sq.mu.b) != 1) {
           if (p.abund.re == 1) {
-            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
           	   p.abund.re, " with elements corresponding to sigma.sq.mus' scale", sep = ""))
           } else {
-            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+            stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
           	   p.abund.re, " or 1with elements corresponding to sigma.sq.mus' scale", sep = ""))
           }
         }
@@ -312,7 +312,7 @@ abund <- function(formula, data, inits, priors, tuning,
           sigma.sq.mu.b <- rep(sigma.sq.mu.b, p.abund.re)
         }
     }   else {
-        if (verbose) {	    
+        if (verbose) {
           message("No prior specified for sigma.sq.mu.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
         }
         sigma.sq.mu.a <- rep(0.1, p.abund.re)
@@ -334,8 +334,8 @@ abund <- function(formula, data, inits, priors, tuning,
         if (verbose) {
           message("No prior specified for kappa.unif.\nSetting uniform bounds of 0 and 100.\n")
         }
-        kappa.a <- 0 
-        kappa.b <- 100 
+        kappa.a <- 0
+        kappa.b <- 100
       }
     } else {
       kappa.a <- 0
@@ -374,10 +374,10 @@ abund <- function(formula, data, inits, priors, tuning,
         sigma.sq.mu.inits <- inits[["sigma.sq.mu"]]
         if (length(sigma.sq.mu.inits) != p.abund.re & length(sigma.sq.mu.inits) != 1) {
           if (p.abund.re == 1) {
-            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re, 
+            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re,
         	       sep = ""))
           } else {
-            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re, 
+            stop(paste("error: initial values for sigma.sq.mu must be of length ", p.abund.re,
         	       " or 1", sep = ""))
           }
         }
@@ -439,9 +439,9 @@ abund <- function(formula, data, inits, priors, tuning,
       }
       beta.tuning <- tuning$beta
       if (length(beta.tuning) != 1 & length(beta.tuning) != p.abund) {
-        stop(paste("error: beta tuning must be a single value or a vector of length ", 
+        stop(paste("error: beta tuning must be a single value or a vector of length ",
           	 p.abund, sep = ''))
-      } 
+      }
       if (length(beta.tuning) == 1) {
         beta.tuning <- rep(beta.tuning, p.abund)
       }
@@ -453,10 +453,10 @@ abund <- function(formula, data, inits, priors, tuning,
         beta.star.tuning <- tuning$beta.star
         if (length(beta.star.tuning) != 1) {
           stop("error: beta.star tuning must be a single value")
-        } 
+        }
         beta.star.tuning <- rep(beta.star.tuning, n.abund.re)
       } else {
-        beta.star.tuning <- NULL 
+        beta.star.tuning <- NULL
       }
       if (family == 'NB') {
         # kappa ---------------------------
@@ -466,12 +466,12 @@ abund <- function(formula, data, inits, priors, tuning,
         kappa.tuning <- tuning$kappa
         if (length(kappa.tuning) != 1) {
           stop("error: kappa tuning must be a single value")
-        } 
+        }
       } else {
         kappa.tuning <- NULL
       }
     }
-    tuning.c <- log(c(beta.tuning, beta.star.tuning, 
+    tuning.c <- log(c(beta.tuning, beta.star.tuning,
           	    kappa.tuning))
     curr.chain <- 1
 
@@ -509,8 +509,8 @@ abund <- function(formula, data, inits, priors, tuning,
     storage.mode(n.report) <- "integer"
     chain.info <- c(curr.chain, n.chains)
     storage.mode(chain.info) <- "integer"
-    n.post.samples <- length(seq(from = n.burn + 1, 
-        			 to = n.samples, 
+    n.post.samples <- length(seq(from = n.burn + 1,
+        			 to = n.samples,
         			 by = as.integer(n.thin)))
     storage.mode(n.post.samples) <- "integer"
     samples.info <- c(n.burn, n.thin, n.post.samples)
@@ -546,33 +546,33 @@ abund <- function(formula, data, inits, priors, tuning,
       }
       storage.mode(chain.info) <- "integer"
       # Run the model in C
-      out.tmp[[i]] <- .Call("abund", y, X, X.re, X.random, consts, n.abund.re.long, 
-          		   beta.inits, kappa.inits, sigma.sq.mu.inits, beta.star.inits, 
-        		           site.indx, beta.star.indx, 
+      out.tmp[[i]] <- .Call("abund", y, X, X.re, X.random, consts, n.abund.re.long,
+          		   beta.inits, kappa.inits, sigma.sq.mu.inits, beta.star.inits,
+        		           site.indx, beta.star.indx,
         		           beta.level.indx, mu.beta, Sigma.beta, kappa.a, kappa.b,
-        		           sigma.sq.mu.a, sigma.sq.mu.b,  
-        		           tuning.c, n.batch, batch.length, accept.rate, 
-        		           n.omp.threads, verbose, n.report, samples.info, chain.info, 
+        		           sigma.sq.mu.a, sigma.sq.mu.b,
+        		           tuning.c, n.batch, batch.length, accept.rate,
+        		           n.omp.threads, verbose, n.report, samples.info, chain.info,
                              family.c, offset)
       chain.info[1] <- chain.info[1] + 1
-    } # i   
+    } # i
     # Calculate R-Hat ---------------
     out <- list()
     out$rhat <- list()
     if (n.chains > 1) {
-      # as.vector removes the "Upper CI" when there is only 1 variable. 
-      out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					      mcmc(t(a$beta.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
+      # as.vector removes the "Upper CI" when there is only 1 variable.
+      out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					      mcmc(t(a$beta.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
       if (p.abund.re > 0) {
-      out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					      mcmc(t(a$sigma.sq.mu.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
+      out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					      mcmc(t(a$sigma.sq.mu.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
       }
       if (family == 'NB') {
-        out$rhat$kappa <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        						       mcmc(t(a$kappa.samples)))), 
-        					autoburnin = FALSE)$psrf[, 2])
+        out$rhat$kappa <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        						       mcmc(t(a$kappa.samples)))),
+        					autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
       }
     } else {
       out$rhat$beta <- rep(NA, p.abund)
@@ -651,7 +651,7 @@ abund <- function(formula, data, inits, priors, tuning,
     out$n.thin <- n.thin
     out$n.burn <- n.burn
     out$n.chains <- n.chains
-    out$dist <- family 
+    out$dist <- family
     out$re.cols <- re.cols
     if (p.abund.re > 0) {
       out$muRE <- TRUE
