@@ -1,9 +1,9 @@
-sfMsAbundGaussian <- function(formula, data, inits, priors, 
-                  tuning, cov.model = 'exponential', NNGP = TRUE, 
-                  n.neighbors = 15, search.type = "cb", n.factors, 
+sfMsAbundGaussian <- function(formula, data, inits, priors,
+                  tuning, cov.model = 'exponential', NNGP = TRUE,
+                  n.neighbors = 15, search.type = "cb", n.factors,
                   n.batch, batch.length, accept.rate = 0.43, family = 'Gaussian',
-                  n.omp.threads = 1, verbose = TRUE, n.report = 100, 
-                  n.burn = round(.10 * n.batch * batch.length), 
+                  n.omp.threads = 1, verbose = TRUE, n.report = 100,
+                  n.burn = round(.10 * n.batch * batch.length),
                   n.thin = 1, n.chains = 1, save.fitted = TRUE, ...){
 
   ptm <- proc.time()
@@ -14,7 +14,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     cat("\tPreparing to run the model\n");
     cat("----------------------------------------\n");
   }
-  # Check for unused arguments ------------------------------------------	
+  # Check for unused arguments ------------------------------------------
   formal.args <- names(formals(sys.function(sys.parent())))
   elip.args <- names(list(...))
   for(i in elip.args){
@@ -22,14 +22,14 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
           warning("'",i, "' is not an argument")
   }
   # Call ----------------------------------------------------------------
-  # Returns a call in which all of the specified arguments are 
-  # specified by their full names. 
+  # Returns a call in which all of the specified arguments are
+  # specified by their full names.
   cl <- match.call()
 
   # Some initial checks -------------------------------------------------
   # Only implemented for NNGP
   if (!NNGP) {
-    stop("error: sfMsAbundGaussian is currently only implemented for NNGPs, not full Gaussian Processes. Please set NNGP = TRUE.") 
+    stop("error: sfMsAbundGaussian is currently only implemented for NNGPs, not full Gaussian Processes. Please set NNGP = TRUE.")
   }
   if (missing(data)) {
     stop("error: data must be specified")
@@ -95,7 +95,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     z <- matrix(1, nrow(y), ncol(y))
   }
 
-  # First subset covariates to only use those that are included in the analysis. 
+  # First subset covariates to only use those that are included in the analysis.
   # Get occurrence covariates in proper format
   # Subset covariates to only use those that are included in the analysis
   data$covs <- data$covs[names(data$covs) %in% all.vars(formula)]
@@ -108,9 +108,9 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
 
   # Neighbors and Ordering ----------------------------------------------
   if (NNGP) {
-    u.search.type <- 2 
-    ## Order by x column. Could potentially allow this to be user defined. 
-    ord <- order(coords[,1]) 
+    u.search.type <- 2
+    ## Order by x column. Could potentially allow this to be user defined.
+    ord <- order(coords[,1])
     # Reorder everything to align with NN ordering
     y <- y[, ord, drop = FALSE]
     z <- z[, ord, drop = FALSE]
@@ -122,18 +122,18 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
   # Checking missing values ---------------------------------------------
   # covs ------------------------
   if (sum(is.na(data$covs)) != 0) {
-    stop("error: missing values in covs. Please remove these sites from all objects in data or somehow replace the NA values with non-missing values (e.g., mean imputation).") 
+    stop("error: missing values in covs. Please remove these sites from all objects in data or somehow replace the NA values with non-missing values (e.g., mean imputation).")
   }
 
   # Check whether random effects are sent in as numeric, and
-  # return error if they are. 
+  # return error if they are.
   # Abundance -------------------------
   if (!is.null(findbars(formula))) {
     abund.re.names <- unique(unlist(sapply(findbars(formula), all.vars)))
     for (i in 1:length(abund.re.names)) {
       if (is(data$covs[, abund.re.names[i]], 'factor')) {
         stop(paste("error: random effect variable ", abund.re.names[i], " specified as a factor. Random effect variables must be specified as numeric.", sep = ''))
-      } 
+      }
       if (is(data$covs[, abund.re.names[i]], 'character')) {
         stop(paste("error: random effect variable ", abund.re.names[i], " specified as character. Random effect variables must be specified as numeric.", sep = ''))
       }
@@ -166,11 +166,11 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
   x.re.names <- x.random.names
 
   # Extract data from inputs --------------------------------------------
-  # Number of species 
+  # Number of species
   N <- dim(y)[1]
   # Number of latent factors
   q <- n.factors
-  # Number of fixed effects 
+  # Number of fixed effects
   p <- ncol(X)
   # Number of random effect parameters
   p.re <- ncol(X.re)
@@ -193,7 +193,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     stop("error: n.thin must be less than n.samples")
   }
 
-  # y is ordered by site, then species within site. 
+  # y is ordered by site, then species within site.
   y.orig <- y
   y <- c(y)
 
@@ -215,10 +215,10 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       message("Beta parameters will be estimated independently\n")
       ind.betas <- TRUE
     } else if (priors$independent.betas == FALSE) {
-      ind.betas <- FALSE 
+      ind.betas <- FALSE
     }
   } else {
-    ind.betas <- FALSE 
+    ind.betas <- FALSE
   }
   # beta.comm -----------------------
   if ("beta.comm.normal" %in% names(priors)) {
@@ -258,7 +258,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     }
     mu.beta.comm <- rep(0, p)
     sigma.beta.comm <- rep(1000, p)
-    Sigma.beta.comm <- diag(p) * 1000 
+    Sigma.beta.comm <- diag(p) * 1000
   }
 
   # tau.sq.beta -----------------------
@@ -270,19 +270,19 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     tau.sq.beta.b <- priors$tau.sq.beta.ig[[2]]
     if (length(tau.sq.beta.a) != p & length(tau.sq.beta.a) != 1) {
       if (p == 1) {
-        stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ", 
+        stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ",
       	   p, " with elements corresponding to tau.sq.betas' shape", sep = ""))
       } else {
-        stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ", 
+        stop(paste("error: tau.sq.beta.ig[[1]] must be a vector of length ",
       	   p, " or 1 with elements corresponding to tau.sq.betas' shape", sep = ""))
       }
     }
     if (length(tau.sq.beta.b) != p & length(tau.sq.beta.b) != 1) {
       if (p == 1) {
-        stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ", 
+        stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ",
       	   p, " with elements corresponding to tau.sq.betas' scale", sep = ""))
       } else {
-        stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ", 
+        stop(paste("error: tau.sq.beta.ig[[2]] must be a vector of length ",
       	   p, " or 1 with elements corresponding to tau.sq.betas' scale", sep = ""))
       }
     }
@@ -293,13 +293,13 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       tau.sq.beta.b <- rep(tau.sq.beta.b, p)
     }
   } else {
-    if (verbose & !ind.betas) {	    
+    if (verbose & !ind.betas) {
       message("No prior specified for tau.sq.beta.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
     }
     tau.sq.beta.a <- rep(0.1, p)
     tau.sq.beta.b <- rep(0.1, p)
   }
-  
+
   # tau.sq -----------------------
   if ("tau.sq.ig" %in% names(priors)) {
     if (!is.list(priors$tau.sq.ig) | length(priors$tau.sq.ig) != 2) {
@@ -308,11 +308,11 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     tau.sq.a <- priors$tau.sq.ig[[1]]
     tau.sq.b <- priors$tau.sq.ig[[2]]
     if (length(tau.sq.a) != N & length(tau.sq.a) != 1) {
-      stop(paste("error: tau.sq.ig[[1]] must be a vector of length ", 
+      stop(paste("error: tau.sq.ig[[1]] must be a vector of length ",
       	   N, " or 1 with elements corresponding to tau.sqs' shape", sep = ""))
     }
     if (length(tau.sq.b) != N & length(tau.sq.b) != 1) {
-      stop(paste("error: tau.sq.ig[[2]] must be a vector of length ", 
+      stop(paste("error: tau.sq.ig[[2]] must be a vector of length ",
       	   p, " or 1 with elements corresponding to tau.sqs' scale", sep = ""))
     }
     if (length(tau.sq.a) != N) {
@@ -322,7 +322,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       tau.sq.b <- rep(tau.sq.b, N)
     }
   } else {
-    if (verbose) {	    
+    if (verbose) {
       message("No prior specified for tau.sq.ig.\nSetting prior shape to 0.01 and prior scale to 0.01\n")
     }
     tau.sq.a <- rep(0.01, N)
@@ -338,11 +338,11 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       phi.a <- priors$phi.unif[[1]]
       phi.b <- priors$phi.unif[[2]]
       if (length(phi.a) != q & length(phi.a) != 1) {
-        stop(paste("error: phi.unif[[1]] must be a vector of length ", 
+        stop(paste("error: phi.unif[[1]] must be a vector of length ",
         	   q, " or 1 with elements corresponding to phis' lower bound for each latent factor", sep = ""))
       }
       if (length(phi.b) != q & length(phi.b) != 1) {
-        stop(paste("error: phi.unif[[2]] must be a vector of length ", 
+        stop(paste("error: phi.unif[[2]] must be a vector of length ",
         	   q, " or 1 with elements corresponding to phis' upper bound for each latent factor", sep = ""))
       }
       if (length(phi.a) != q) {
@@ -370,11 +370,11 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
         stop("error: nu.unif must be a list of length 2")
       }
       if (length(nu.a) != q & length(nu.a) != 1) {
-        stop(paste("error: nu.unif[[1]] must be a vector of length ", 
+        stop(paste("error: nu.unif[[1]] must be a vector of length ",
         	   q, " or 1 with elements corresponding to nus' lower bound for each latent factor", sep = ""))
       }
       if (length(nu.b) != q & length(nu.b) != 1) {
-        stop(paste("error: nu.unif[[2]] must be a vector of length ", 
+        stop(paste("error: nu.unif[[2]] must be a vector of length ",
         	   q, " or 1 with elements corresponding to nus' upper bound for each latent factor", sep = ""))
       }
       if (length(nu.a) != q) {
@@ -398,19 +398,19 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       sigma.sq.mu.b <- priors$sigma.sq.mu.ig[[2]]
       if (length(sigma.sq.mu.a) != p.re & length(sigma.sq.mu.a) != 1) {
         if (p.re == 1) {
-        stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+        stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
         	   p.re, " with elements corresponding to sigma.sq.mus' shape", sep = ""))
         } else {
-        stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ", 
+        stop(paste("error: sigma.sq.mu.ig[[1]] must be a vector of length ",
         	   p.re, " or 1 with elements corresponding to sigma.sq.mus' shape", sep = ""))
         }
       }
       if (length(sigma.sq.mu.b) != p.re & length(sigma.sq.mu.b) != 1) {
         if (p.re == 1) {
-          stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
         	   p.re, " with elements corresponding to sigma.sq.mus' scale", sep = ""))
         } else {
-          stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ", 
+          stop(paste("error: sigma.sq.mu.ig[[2]] must be a vector of length ",
         	   p.re, " or 1with elements corresponding to sigma.sq.mus' scale", sep = ""))
         }
       }
@@ -421,7 +421,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
         sigma.sq.mu.b <- rep(sigma.sq.mu.b, p.re)
       }
   }   else {
-      if (verbose) {	    
+      if (verbose) {
         message("No prior specified for sigma.sq.mu.ig.\nSetting prior shape to 0.1 and prior scale to 0.1\n")
       }
       sigma.sq.mu.a <- rep(0.1, p.re)
@@ -443,10 +443,10 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     beta.comm.inits <- inits[["beta.comm"]]
     if (length(beta.comm.inits) != p & length(beta.comm.inits) != 1) {
       if (p == 1) {
-        stop(paste("error: initial values for beta.comm must be of length ", p, 
+        stop(paste("error: initial values for beta.comm must be of length ", p,
       	   sep = ""))
       } else {
-        stop(paste("error: initial values for beta.comm must be of length ", p, 
+        stop(paste("error: initial values for beta.comm must be of length ", p,
       	   , " or 1", sep = ""))
       }
     }
@@ -465,10 +465,10 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     tau.sq.beta.inits <- inits[["tau.sq.beta"]]
     if (length(tau.sq.beta.inits) != p & length(tau.sq.beta.inits) != 1) {
       if (p == 1) {
-        stop(paste("error: initial values for tau.sq.beta must be of length ", p, 
+        stop(paste("error: initial values for tau.sq.beta must be of length ", p,
       	   sep = ""))
       } else {
-        stop(paste("error: initial values for tau.sq.beta must be of length ", p, 
+        stop(paste("error: initial values for tau.sq.beta must be of length ", p,
       	   " or 1", sep = ""))
       }
     }
@@ -486,7 +486,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
   if ("tau.sq" %in% names(inits)) {
     tau.sq.inits <- inits[["tau.sq"]]
     if (length(tau.sq.inits) != N & length(tau.sq.inits) != 1) {
-      stop(paste("error: initial values for tau.sq must be of length ", N, 
+      stop(paste("error: initial values for tau.sq must be of length ", N,
       	   " or 1", sep = ""))
     }
     if (length(tau.sq.inits) != N) {
@@ -499,18 +499,18 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     }
   }
   # beta ----------------------------
-  # ORDER: N x p matrix sent in as a column-major vector ordered by 
-  #        parameter then species within parameter. 
+  # ORDER: N x p matrix sent in as a column-major vector ordered by
+  #        parameter then species within parameter.
   if ("beta" %in% names(inits)) {
     beta.inits <- inits[["beta"]]
     if (is.matrix(beta.inits)) {
       if (ncol(beta.inits) != p | nrow(beta.inits) != N) {
-        stop(paste("error: initial values for beta must be a matrix with dimensions ", 
+        stop(paste("error: initial values for beta must be a matrix with dimensions ",
         	   N, "x", p, " or a single numeric value", sep = ""))
       }
     }
     if (!is.matrix(beta.inits) & length(beta.inits) != 1) {
-      stop(paste("error: initial values for beta must be a matrix with dimensions ", 
+      stop(paste("error: initial values for beta must be a matrix with dimensions ",
       	   N, " x ", p, " or a single numeric value", sep = ""))
     }
     if (length(beta.inits) == 1) {
@@ -522,15 +522,15 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
         message('beta is not specified in initial values.\nSetting initial values to random values from the community-level normal distribution\n')
       }
   }
-  # Create a N * p x 1 matrix of the species-level regression coefficients. 
-  # This is ordered by parameter, then species within a parameter. 
+  # Create a N * p x 1 matrix of the species-level regression coefficients.
+  # This is ordered by parameter, then species within a parameter.
   beta.inits <- c(beta.inits)
   # phi -----------------------------
   # ORDER: a length N vector ordered by species in the detection-nondetection data.
   if ("phi" %in% names(inits)) {
     phi.inits <- inits[["phi"]]
     if (length(phi.inits) != q & length(phi.inits) != 1) {
-      stop(paste("error: initial values for phi must be of length ", q, " or 1", 
+      stop(paste("error: initial values for phi must be of length ", q, " or 1",
       	   sep = ""))
     }
     if (length(phi.inits) != q) {
@@ -563,8 +563,8 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     }
   }
   # lambda ----------------------------
-  # ORDER: an n.sp x q matrix sent in as a column-major vector, which is ordered by 
-  #        factor, then species within factor. 
+  # ORDER: an n.sp x q matrix sent in as a column-major vector, which is ordered by
+  #        factor, then species within factor.
   if ("lambda" %in% names(inits)) {
     lambda.inits <- inits[["lambda"]]
     if (!is.matrix(lambda.inits)) {
@@ -589,7 +589,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       message("lambda is not specified in initial values.\nSetting initial values of the lower triangle to 0\n")
     }
     # lambda.inits are organized by factor, then by species. This is necessary for working
-    # with dgemv.  
+    # with dgemv.
     lambda.inits <- c(lambda.inits)
   }
   # w -----------------------------
@@ -619,10 +619,10 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       sigma.sq.mu.inits <- inits[["sigma.sq.mu"]]
       if (length(sigma.sq.mu.inits) != p.re & length(sigma.sq.mu.inits) != 1) {
         if (p.re == 1) {
-          stop(paste("error: initial values for sigma.sq.mu must be of length ", p.re, 
+          stop(paste("error: initial values for sigma.sq.mu must be of length ", p.re,
       	     sep = ""))
         } else {
-          stop(paste("error: initial values for sigma.sq.mu must be of length ", p.re, 
+          stop(paste("error: initial values for sigma.sq.mu must be of length ", p.re,
       	     " or 1", sep = ""))
         }
       }
@@ -660,13 +660,13 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
   # Order must match util.cpp spCor.
   cov.model.names <- c("exponential", "spherical", "matern", "gaussian")
   if(! cov.model %in% cov.model.names){
-    stop("error: specified cov.model '",cov.model,"' is not a valid option; choose from ", 
+    stop("error: specified cov.model '",cov.model,"' is not a valid option; choose from ",
          paste(cov.model.names, collapse=", ", sep="") ,".")}
   # Obo for cov model lookup on c side
   cov.model.indx <- which(cov.model == cov.model.names) - 1
 
   # Get tuning values ---------------------------------------------------
-  # Not accessed, but necessary to keep things in line with the underlying functions. 
+  # Not accessed, but necessary to keep things in line with the underlying functions.
   sigma.sq.tuning <- rep(0, q)
   phi.tuning <- rep(0, q)
   nu.tuning <- rep(0, q)
@@ -715,10 +715,10 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       names(re.cols)[j] <- split.names[[j]][2]
     }
   }
- 
+
   if (!NNGP) {
 
-    stop("error: sfMsAbund is currently only implemented for NNGPs, not full Gaussian Processes. Please set NNGP = TRUE.") 
+    stop("error: sfMsAbund is currently only implemented for NNGPs, not full Gaussian Processes. Please set NNGP = TRUE.")
 
   } else {
 
@@ -730,32 +730,32 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     }
 
     search.type.names <- c("brute", "cb")
-    
+
     if(!search.type %in% search.type.names){
       stop("error: specified search.type '",search.type,
-	   "' is not a valid option; choose from ", 
+	   "' is not a valid option; choose from ",
 	   paste(search.type.names, collapse=", ", sep="") ,".")
     }
-    
+
     ## Indexes
     if(search.type == "brute"){
       indx <- mkNNIndx(coords, n.neighbors, n.omp.threads)
     } else{
       indx <- mkNNIndxCB(coords, n.neighbors, n.omp.threads)
     }
-    
+
     nn.indx <- indx$nnIndx
     nn.indx.lu <- indx$nnIndxLU
     nn.indx.run.time <- indx$run.time
-    
+
     if(verbose){
       cat("----------------------------------------\n");
       cat("Building the neighbors of neighbors list\n");
       cat("----------------------------------------\n");
     }
-    
+
     indx <- mkUIndx(J, n.neighbors, nn.indx, nn.indx.lu, u.search.type)
-    
+
     u.indx <- indx$u.indx
     u.indx.lu <- indx$u.indx.lu
     ui.indx <- indx$ui.indx
@@ -803,8 +803,8 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     # chain.info order: current chain, total number of chains
     chain.info <- c(curr.chain, n.chains)
     storage.mode(chain.info) <- "integer"
-    n.post.samples <- length(seq(from = n.burn + 1, 
-				 to = n.samples, 
+    n.post.samples <- length(seq(from = n.burn + 1,
+				 to = n.samples,
 				 by = as.integer(n.thin)))
     # samples.info order: burn-in, thinning rate, number of posterior samples
     samples.info <- c(n.burn, n.thin, n.post.samples)
@@ -831,11 +831,11 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     for (i in 1:n.chains) {
       # Change initial values if i > 1
       if ((i > 1) & (!fix.inits)) {
-        if (!ind.betas) {	      
+        if (!ind.betas) {
           beta.comm.inits <- rnorm(p, mu.beta.comm, sqrt(sigma.beta.comm))
           tau.sq.beta.inits <- runif(p, 0.5, 10)
 	}
-        beta.inits <- matrix(rnorm(N * p, beta.comm.inits, 
+        beta.inits <- matrix(rnorm(N * p, beta.comm.inits,
               		     sqrt(tau.sq.beta.inits)), N, p)
         beta.inits <- c(beta.inits)
         tau.sq.inits <- runif(N, 0.01, 3)
@@ -856,52 +856,52 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
 
       storage.mode(chain.info) <- "integer"
       # Run the model in C
-      out.tmp[[i]] <- .Call("sfMsAbundGaussianNNGP", y, X, coords, X.re, 
-			    X.random, consts, n.re.long, 
+      out.tmp[[i]] <- .Call("sfMsAbundGaussianNNGP", y, X, coords, X.re,
+			    X.random, consts, n.re.long,
         	            n.neighbors, nn.indx, nn.indx.lu, u.indx, u.indx.lu, ui.indx,
         	            beta.inits, beta.comm.inits, tau.sq.beta.inits, tau.sq.inits,
-        	            phi.inits, lambda.inits, nu.inits, w.inits, sigma.sq.mu.inits, 
-        		    beta.star.inits, beta.star.indx, beta.level.indx, mu.beta.comm, 
+        	            phi.inits, lambda.inits, nu.inits, w.inits, sigma.sq.mu.inits,
+        		    beta.star.inits, beta.star.indx, beta.level.indx, mu.beta.comm,
         	            Sigma.beta.comm,
         	            tau.sq.beta.a, tau.sq.beta.b, tau.sq.a, tau.sq.b, phi.a, phi.b,
-        	            nu.a, nu.b, sigma.sq.mu.a, sigma.sq.mu.b, 
-        		    tuning.c, cov.model.indx, n.batch, 
-        	            batch.length, accept.rate, n.omp.threads, verbose, n.report, 
+        	            nu.a, nu.b, sigma.sq.mu.a, sigma.sq.mu.b,
+        		    tuning.c, cov.model.indx, n.batch,
+        	            batch.length, accept.rate, n.omp.threads, verbose, n.report,
         	            samples.info, chain.info, z, family.c)
       chain.info[1] <- chain.info[1] + 1
     }
     # Calculate R-Hat ---------------
     out$rhat <- list()
     if (n.chains > 1) {
-      # as.vector removes the "Upper CI" when there is only 1 variable. 
+      # as.vector removes the "Upper CI" when there is only 1 variable.
       if (!ind.betas) {
-        out$rhat$beta.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					      mcmc(t(a$beta.comm.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2])
-        out$rhat$tau.sq.beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					      mcmc(t(a$tau.sq.beta.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2])
+        out$rhat$beta.comm <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					      mcmc(t(a$beta.comm.samples)))),
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+        out$rhat$tau.sq.beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					      mcmc(t(a$tau.sq.beta.samples)))),
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
       } else {
         out$rhat$beta.comm <- rep(NA, p)
         out$rhat$tau.sq.beta <- rep(NA, p)
       }
-      out$rhat$tau.sq <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					      mcmc(t(a$tau.sq.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
-      out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					         mcmc(t(a$beta.samples)))), 
-      			     autoburnin = FALSE)$psrf[, 2])
-      out$rhat$theta <- gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-      					      mcmc(t(a$theta.samples)))), 
-      			      autoburnin = FALSE)$psrf[, 2]
+      out$rhat$tau.sq <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					      mcmc(t(a$tau.sq.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+      out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					         mcmc(t(a$beta.samples)))),
+      			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
+      out$rhat$theta <- gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+      					      mcmc(t(a$theta.samples)))),
+      			      autoburnin = FALSE, multivariate = FALSE)$psrf[, 2]
       lambda.mat <- matrix(lambda.inits, N, q)
-      out$rhat$lambda.lower.tri <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					       mcmc(t(a$lambda.samples[c(lower.tri(lambda.mat)), ])))), 
-        					       autoburnin = FALSE)$psrf[, 2])
+      out$rhat$lambda.lower.tri <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					       mcmc(t(a$lambda.samples[c(lower.tri(lambda.mat)), ])))),
+        					       autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
       if (p.re > 0) {
-        out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					      mcmc(t(a$sigma.sq.mu.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2])
+        out$rhat$sigma.sq.mu <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a)
+        					      mcmc(t(a$sigma.sq.mu.samples)))),
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
       }
     } else {
       out$rhat$beta.comm <- rep(NA, p)
@@ -917,7 +917,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     # Put everything into MCMC objects
     out$beta.comm.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$beta.comm.samples))))
     colnames(out$beta.comm.samples) <- x.names
-    out$tau.sq.beta.samples <- mcmc(do.call(rbind, 
+    out$tau.sq.beta.samples <- mcmc(do.call(rbind,
       				lapply(out.tmp, function(a) t(a$tau.sq.beta.samples))))
     colnames(out$tau.sq.beta.samples) <- x.names
 
@@ -928,7 +928,7 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
     out$beta.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$beta.samples))))
     colnames(out$beta.samples) <- coef.names
     out$tau.sq.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$tau.sq.samples))))
-    colnames(out$tau.sq.samples) <- sp.names 
+    colnames(out$tau.sq.samples) <- sp.names
     if (p.re > 0) {
       out$sigma.sq.mu.samples <- mcmc(
         do.call(rbind, lapply(out.tmp, function(a) t(a$sigma.sq.mu.samples))))
@@ -949,23 +949,23 @@ sfMsAbundGaussian <- function(formula, data, inits, priors,
       theta.names <- paste(rep(c('phi'), each = q), 1:q, sep = '-')
     } else {
       theta.names <- paste(rep(c('phi', 'nu'), each = q), 1:q, sep = '-')
-    } 
+    }
     colnames(out$theta.samples) <- theta.names
 
-    out$w.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$w.samples, 
+    out$w.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$w.samples,
       								dim = c(q, J, n.post.samples))))
     out$w.samples <- out$w.samples[, order(ord), , drop = FALSE]
     out$w.samples <- aperm(out$w.samples, c(3, 1, 2))
     if (save.fitted) {
-      out$mu.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$mu.samples, 
+      out$mu.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$mu.samples,
         								dim = c(N, J, n.post.samples))))
       out$mu.samples <- out$mu.samples[, order(ord), ]
       out$mu.samples <- aperm(out$mu.samples, c(3, 1, 2))
-      out$like.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$like.samples, 
+      out$like.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$like.samples,
         								dim = c(N, J, n.post.samples))))
       out$like.samples <- out$like.samples[, order(ord), ]
       out$like.samples <- aperm(out$like.samples, c(3, 1, 2))
-      out$y.rep.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$y.rep.samples, 
+      out$y.rep.samples <- do.call(abind, lapply(out.tmp, function(a) array(a$y.rep.samples,
         								dim = c(N, J, n.post.samples))))
       out$y.rep.samples <- out$y.rep.samples[, order(ord), ]
       out$y.rep.samples <- aperm(out$y.rep.samples, c(3, 1, 2))
